<?php

namespace Drupal\azure_blob_fs\Service;

use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Site\Settings;

/**
 * Defines a service for the Azure Blob File System module.
 */
class AzureBlobFsService implements AzureBlobFsServiceInterface {

  /**
   * The config factory object.
   *
   * @var \Drupal\Core\Config\ConfigFactory
   */
  protected $configFactory;

  /**
   * Constructs an AzureBlobFsService object.
   *
   * @param \Drupal\Core\Config\ConfigFactory $config_factory
   *   The config factory object.
   */
  public function __construct(ConfigFactory $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function wired(): bool {
    return Settings::get('azure_blob_fs.enabled')
      && !empty(Settings::get('azure_blob_fs.use_remote_public_fs'))
      && Settings::get('azure_blob_fs.use_remote_public_fs')
      && !empty(Settings::get('azure_blob_fs.url'))
      && !empty(Settings::get('azure_blob_fs.public_sas_token'))
      && !empty(Settings::get('azure_blob_fs.public_container_name'));
  }

  /**
   * {@inheritdoc}
   */
  public static function privatelyWired(): bool {
    return self::wired()
      && !empty(Settings::get('azure_blob_fs.use_remote_private_fs'))
      && Settings::get('azure_blob_fs.use_remote_private_fs')
      && !empty(Settings::get('azure_blob_fs.account_name'))
      && !empty(Settings::get('azure_blob_fs.account_key'))
      && !empty(Settings::get('azure_blob_fs.private_sas_token'))
      && !empty(Settings::get('azure_blob_fs.private_container_name'));
  }

}
